package com.landray.kmss.sys.attachment.util;

import com.landray.kmss.sys.attachment.model.SysAttSignatureConfig;
import java.util.HashMap;
import com.landray.kmss.sys.attachment.integrate.wps.util.SysAttWpsCenterUtil;
import org.apache.commons.lang3.StringUtils;
import com.landray.kmss.sys.appconfig.model.BaseAppconfigCache;
import com.landray.kmss.sys.attachment.integrate.wps.util.SysAttWpsCloudUtil;
import com.landray.kmss.util.SpringBeanUtil;
import com.landray.kmss.sys.appconfig.service.ISysAppConfigService;
import com.landray.kmss.util.StringUtil;
import java.util.Map;
import com.landray.kmss.sys.attachment.model.SysAttConfig;
import org.slf4j.LoggerFactory;
import com.landray.kmss.sys.filestore.service.ISysFileConvertConfigService;
import org.slf4j.Logger;

public class SysAttConfigUtil
{
    private static final Logger logger;
    private static ISysFileConvertConfigService sysFileConvertConfigService;
    
    static {
        logger = LoggerFactory.getLogger(SysAttConfigUtil.class);
    }
    
    public static String getOnlineToolType() throws Exception {
        final SysAttConfig config = new SysAttConfig();
        final Map map = config.getDataMap();
        if (!map.isEmpty()) {
            final String onlineToolType = map.getOrDefault("onlineToolType", "0");
            return onlineToolType;
        }
        return "0";
    }
    
    public static String getMobileOnlineToolType() throws Exception {
        final SysAttConfig config = new SysAttConfig();
        final Map map = config.getDataMap();
        final String pc = getOnlineToolType();
        String result = "";
        final String s;
        switch (s = pc) {
            case "0": {
                result = map.get("onlineMobileToolTypeFirst");
                break;
            }
            case "1": {
                result = map.get("onlineMobileToolTypeThird");
                break;
            }
            case "3": {
                result = map.get("onlineMobileToolTypeSecond");
                break;
            }
            case "4": {
                result = map.get("onlineMobileToolTypeFourth");
                break;
            }
            default:
                break;
        }
        if (StringUtil.isNull(result)) {
            result = "";
        }
        return result;
    }
    
    public static boolean isWritingByWps() throws Exception {
        boolean isWps = false;
        final Map map = getCowritingPluginConfigs();
        if (!map.isEmpty()) {
            final String writingTool = map.getOrDefault("kms.cowriting.wordPlugin.writingtool", "wps");
            if ("wps".equals(writingTool)) {
                isWps = true;
            }
        }
        return isWps;
    }
    
    public static Map<String, Object> getCowritingPluginConfigs() throws Exception {
        final ISysAppConfigService sysAppConfigService = (ISysAppConfigService)SpringBeanUtil.getBean("sysAppConfigService");
        final Map<String, Object> map = sysAppConfigService.findByKey("com.landray.kmss.kms.cowriting.config.CowritingPluginConfig");
        return map;
    }
    
    public static String isShowWindow() throws Exception {
        final SysAttConfig config = new SysAttConfig();
        final Map map = config.getDataMap();
        if (!map.isEmpty()) {
            final String showWindow = map.get("showWindow");
            return showWindow;
        }
        return "1";
    }
    
    public static String isReadPdf() throws Exception {
        final SysAttConfig config = new SysAttConfig();
        final Map map = config.getDataMap();
        if (!map.isEmpty()) {
            final String readpdf = map.get("readpdf");
            return readpdf;
        }
        return "1";
    }
    
    public static String isReadJGForMobile() throws Exception {
        final SysAttConfig config = new SysAttConfig();
        final Map map = config.getDataMap();
        if (!map.isEmpty()) {
            final String readpdf = map.get("onlineMobileToolTypeFirst");
            return readpdf;
        }
        return "3";
    }
    
    public static String isReadWPSForMobile() throws Exception {
        final SysAttConfig config = new SysAttConfig();
        final Map map = config.getDataMap();
        if (!map.isEmpty()) {
            final String readpdf = map.get("onlineMobileToolTypeSecond");
            return readpdf;
        }
        return "1";
    }
    
    public static String isReadWPSCloudForMobile() throws Exception {
        final SysAttConfig config = new SysAttConfig();
        final Map map = config.getDataMap();
        if (!map.isEmpty()) {
            final String readpdf = map.get("onlineMobileToolTypeThird");
            return readpdf;
        }
        return "2";
    }
    
    public static String isReadWPSCenterForMobile() throws Exception {
        final SysAttConfig config = new SysAttConfig();
        final Map map = config.getDataMap();
        if (!map.isEmpty()) {
            final String readpdf = map.get("onlineMobileToolTypeFourth");
            return readpdf;
        }
        return "2";
    }
    
    public static String isReadWPSCenterV6ForMobile() throws Exception {
        final SysAttConfig config = new SysAttConfig();
        final Map map = config.getDataMap();
        if (!map.isEmpty()) {
            final String readpdf = map.get("onlineMobileToolTypeSix");
            return readpdf;
        }
        return "2";
    }
    
    public static String getConfigInfo(final String configName) throws Exception {
        final SysAttConfig config = new SysAttConfig();
        final Map map = config.getDataMap();
        String onlineToolType = "";
        if (!map.isEmpty()) {
            onlineToolType = map.get(configName);
        }
        return onlineToolType;
    }
    
    public static boolean pdfReadByFoxitPC() throws Exception {
        final SysAttConfig config = new SysAttConfig();
        final Map map = config.getDataMap();
        if (!map.isEmpty()) {
            final String readpdf = map.get("foxitPCEnable");
            return "true".equals(readpdf);
        }
        return false;
    }
    
    public static boolean pdfReadByFoxitMobile() throws Exception {
        final SysAttConfig config = new SysAttConfig();
        final Map map = config.getDataMap();
        if (!map.isEmpty()) {
            final String readpdf = map.get("foxitMobileEnable");
            return "true".equals(readpdf);
        }
        return false;
    }
    
    public static boolean pdfViewByBrowser() throws Exception {
        final SysAttConfig config = new SysAttConfig();
        final Map map = config.getDataMap();
        if (map.isEmpty()) {
            return false;
        }
        final String pdfViewBrowser = map.get("pdfViewBrowser");
        return "true".equals(pdfViewBrowser);
    }
    
    public static boolean ofdViewByBrowser() throws Exception {
        final SysAttConfig config = new SysAttConfig();
        final Map map = config.getDataMap();
        if (map.isEmpty()) {
            return false;
        }
        final String pdfViewBrowser = map.get("ofdViewBrowser");
        return "true".equals(pdfViewBrowser);
    }
    
    public static String useWpsLinuxView() throws Exception {
        final SysAttConfig config = new SysAttConfig();
        final Map map = config.getDataMap();
        if (map.isEmpty()) {
            return Boolean.FALSE.toString();
        }
        final String useView = map.get("useWpsLinuxView");
        final boolean wpsPreviewIsLinux = SysAttWpsCloudUtil.checkWpsPreviewIsLinux();
        final String onlineToolType = getOnlineToolType();
        if ("2".equals(useView) && wpsPreviewIsLinux && ("0".equals(onlineToolType) || "3".equals(onlineToolType))) {
            return Boolean.TRUE.toString();
        }
        return Boolean.FALSE.toString();
    }
    
    public static Boolean isEnbaleDianju() {
        final Map<String, String> dataMap = BaseAppconfigCache.getCacheData("com.landray.kmss.third.dianju.model.ThirdDianjuConfig");
        String config = "";
        if (!dataMap.isEmpty()) {
            config = dataMap.get("thirdDianjuEnabled");
        }
        if (SysAttConfigUtil.logger.isDebugEnabled()) {
            SysAttConfigUtil.logger.debug("获取配置属性名：thirdDianjuEnabled,属性值：{}", config);
        }
        if ("true".equals(config)) {
            return true;
        }
        return false;
    }
    
    public static String getReadOLConfig() throws Exception {
        String v = new SysAttConfig().getDataMap().get("readOLConfig");
        if (StringUtils.isEmpty((CharSequence)v)) {
            v = "-1";
        }
        return v;
    }
    
    public static boolean enableThirdSfsView() throws Exception {
        boolean isThirdSfsEnable = false;
        final String readOLConfig = getReadOLConfig();
        if (("5".equals(readOLConfig) && SysAttWpsCenterUtil.isWpsCenterSfs()) || "4".equals(readOLConfig) || "6".equals(readOLConfig) || "7".equals(readOLConfig) || "8".equals(readOLConfig) || "9".equals(readOLConfig)) {
            isThirdSfsEnable = true;
        }
        return isThirdSfsEnable;
    }
    
    public static boolean enableThirdSfsEdit() throws Exception {
        boolean isThirdSfsEnable = false;
        final String onlineToolType = getOnlineToolType();
        if ("5".equals(onlineToolType) || "6".equals(onlineToolType) || ("4".equals(onlineToolType) && SysAttWpsCenterUtil.isEnable() && SysAttWpsCenterUtil.isWpsCenterSfs())) {
            isThirdSfsEnable = true;
        }
        return isThirdSfsEnable;
    }
    
    public static String[] getThirdSfsViewType() throws Exception {
        final String viewType = getReadOLConfig();
        String[] fileTypeAry = new String[0];
        if ("4".equals(viewType)) {
            fileTypeAry = SysAttConstant.DIANJU_VIEW_TYPE;
        }
        else if ("5".equals(viewType)) {
            fileTypeAry = SysAttConstant.CENTER_VIEW_TYPE;
        }
        else if ("6".equals(viewType)) {
            fileTypeAry = SysAttConstant.FOXIT_VIEW_TYPE;
        }
        else if ("7".equals(viewType)) {
            fileTypeAry = SysAttConstant.YOZO_VIEW_TYPE;
        }
        else if ("8".equals(viewType)) {
            fileTypeAry = SysAttConstant.CENTER_V6_VIEW_TYPE;
        }
        else if ("9".equals(viewType)) {
            fileTypeAry = SysAttConstant.SUWELL_VIEW_TYPE;
        }
        return fileTypeAry;
    }
    
    public static boolean isASPOSEEnabled() {
        if (SysAttConfigUtil.sysFileConvertConfigService == null) {
            SysAttConfigUtil.sysFileConvertConfigService = (ISysFileConvertConfigService)SpringBeanUtil.getBean("sysFileConvertConfigService");
        }
        return "true".equals(SysAttConfigUtil.sysFileConvertConfigService.getGlobalConfigForm().getConverter_aspose());
    }
    
    public static boolean isDianJuOLEnabled() {
        final HashMap<String, String> map = new HashMap<String, String>(BaseAppconfigCache.getCacheData("com.landray.kmss.third.dianju.model.ThirdDianjuReadOLConfig"));
        return map != null && !map.isEmpty() && StringUtils.equals((CharSequence)"true", (CharSequence)map.get("thirdDianjuReadOLEnabled"));
    }
    
    public static boolean isWpsPreviewEnabled() {
        final HashMap<String, String> map = new HashMap<String, String>(BaseAppconfigCache.getCacheData("com.landray.kmss.third.wps.model.ThirdWpsConfig"));
        return map != null && !map.isEmpty() && StringUtils.equals((CharSequence)"true", (CharSequence)map.get("thirdWpsPreviewEnabled"));
    }
    
    public static boolean isWpsCenterEnabled() {
        final HashMap<String, String> map = new HashMap<String, String>(BaseAppconfigCache.getCacheData("com.landray.kmss.third.wps.model.ThirdWpsConfig"));
        return map != null && !map.isEmpty() && StringUtils.equals((CharSequence)"true", (CharSequence)map.get("thirdWpsCenterEnabled"));
    }
    
    public static boolean isWpsCenterV6Enabled() {
        final HashMap<String, String> map = new HashMap<String, String>(BaseAppconfigCache.getCacheData("com.landray.kmss.third.wps.model.ThirdWpsCenterV6Config"));
        return map != null && !map.isEmpty() && StringUtils.equals((CharSequence)"true", (CharSequence)map.get("thirdWpsCenterEnabled"));
    }
    
    public static boolean isFoxitPreviewEnabled() {
        final Map<String, String> dataMap = BaseAppconfigCache.getCacheData("com.landray.kmss.third.foxit.model.ThirdFoxitPreviewConfig");
        return dataMap != null && !dataMap.isEmpty() && StringUtils.equals((CharSequence)"true", (CharSequence)dataMap.get("thirdFoxitPreviewEnabled"));
    }
    
    public static boolean isYozoPreviewEnabled() {
        final Map<String, String> dataMap = BaseAppconfigCache.getCacheData("com.landray.kmss.third.yozo.model.ThirdYozoConfig");
        return dataMap != null && !dataMap.isEmpty() && StringUtils.equals((CharSequence)"true", (CharSequence)dataMap.get("thirdYozoEnabled"));
    }
    
    public static boolean isSuWellPreviewEnabled() {
        final Map<String, String> dataMap = BaseAppconfigCache.getCacheData("com.landray.kmss.third.suwell.config.ThirdSuWellConfig");
        return dataMap != null && !dataMap.isEmpty() && StringUtils.equals((CharSequence)"true", (CharSequence)dataMap.get("thirdSuWellViewEnabled"));
    }
    
    public static boolean thirdDianjuEnabled() throws Exception {
        final Map<String, String> dataMap = BaseAppconfigCache.getCacheData("com.landray.kmss.third.dianju.model.ThirdDianjuConfig");
        return dataMap != null && !dataMap.isEmpty() && ("true".equals(dataMap.get("thirdDianjuEnabled")) && "4".equals(getReadOLConfig()));
    }
    
    public static boolean thirdFoxitEnabled() throws Exception {
        final Map<String, String> dataMap = BaseAppconfigCache.getCacheData("com.landray.kmss.third.foxit.model.ThirdFoxitConfig");
        return dataMap != null && !dataMap.isEmpty() && ("true".equals(dataMap.get("thirdFoxitEnabled")) && "6".equals(getReadOLConfig()));
    }
    
    public static boolean thirdWpsCenterEnabled() throws Exception {
        final Map<String, String> dataMap = BaseAppconfigCache.getCacheData("com.landray.kmss.third.wps.model.ThirdWpsConfig");
        return dataMap != null && !dataMap.isEmpty() && ("true".equals(dataMap.get("thirdWpsCenterEnabled")) && "5".equals(getReadOLConfig()));
    }
    
    public static boolean thirdWpsCenterV6Enabled() throws Exception {
        return isWpsCenterV6Enabled() && "8".equals(getReadOLConfig());
    }
    
    public static Boolean isEnableAttachmentSignature() throws Exception {
        final SysAttSignatureConfig config = new SysAttSignatureConfig();
        final Map map = config.getDataMap();
        if (!map.isEmpty()) {
            final String enableAttachmentSignature = map.get("enableAttachmentSignature");
            if ("1".equals(enableAttachmentSignature)) {
                return true;
            }
        }
        return false;
    }
    
    public static String getAttachmentSignatureType() throws Exception {
        final SysAttSignatureConfig config = new SysAttSignatureConfig();
        final Map map = config.getDataMap();
        if (!map.isEmpty()) {
            final String attachmentSignatureType = map.get("attachementSignatureType");
            if (StringUtil.isNotNull(attachmentSignatureType)) {
                return attachmentSignatureType;
            }
        }
        return "";
    }
}
